@@ -2,11 +2,9 @@ import re
 from copy import copy
 from dataclasses import dataclass, field, fields
 from datetime import datetime, timedelta, timezone
-from enum import Enum
 from itertools import groupby
-from os import environ
 from typing import Optional
-from urllib.parse import parse_qs, urlsplit, quote as urlquote
+from urllib.parse import parse_qs, urlsplit
 
 # import requests  # we use lazy imports to improve load time for local commands
 # from bs4 import BeautifulSoup
@@ -15,9 +13,16 @@ import click
 from tqdm import tqdm
 
 from kks.errors import APIError, ParseError
+from kks.util.common import deprecated
+from kks.util.ejudge import Lang, Links, Page
 from kks.util.h2t import HTML2Text
 
 
+"""
+This module contains parsers for ejudge pages anc (mostly) CLI-app-specific classes.
+"""
+
+
 CONTEST_ID_BY_GROUP = {}
 CONTEST_ID_BY_GROUP.update({
     f'19{group}': 130 + group for group in range(1, 12)
@@ -38,26 +43,10 @@ TIME_FORMAT = '%Y/%m/%d %H:%M:%S'
 MSK_TZ = timezone(timedelta(hours=3))
 
 
-class Links:
-    SCHEME = environ.get('KKS_CUSTOM_SCHEME', 'https')
-    DOMAIN = environ.get('KKS_CUSTOM_DOMAIN', 'caos.myltsev.ru')
-    CGI_BIN = f'{SCHEME}://{DOMAIN}/cgi-bin'
-    WEB_CLIENT_ROOT = f'{CGI_BIN}/new-client'
-
-
-class Page(Enum):
-    MAIN_PAGE = 2
-    VIEW_SOURCE = 36
-    DOWNLOAD_SOURCE = 91
-    USER_STANDINGS = 94
-    SUMMARY = 137
-    SUBMISSIONS = 140
-    SUBMIT_CLAR = 141
-    CLARS = 142
-    SETTINGS = 143
-
-
 class Status:
+    """Text-only statuses."""
+
+    # TODO Add text status parsing to RunStatus and remove this class?
     OK = 'OK'
     OK_AUTO = 'OK (auto)'  # only in summary
     REVIEW = 'Pending review'
@@ -71,50 +60,6 @@ class Status:
     NOT_SUBMITTED = 'Not submitted'
 
 
-class Lang(Enum):
-    def __new__(cls, value, suf, realname=None):
-        obj = object.__new__(cls)
-        obj._value_ = value
-        obj.realname = realname
-        obj.suf = suf
-        return obj
-
-    @property
-    def name(self):
-        if self.realname is not None:
-            return self.realname
-        return self._name_
-
-    # NOTE compiler ids may change
-    gcc = (2, '.c')
-    gxx = (3, '.cpp', 'g++')
-    python = (13, '.py')
-    perl = (14, '.pl')
-    ruby = (21, '.rb')
-    python3 = (23, '.py')
-    make = (25, '.tar')
-    gcc_vg = (28, '.c', 'gcc-vg')
-    gxx_vg = (29, '.cpp', 'g++-vg')
-    clang = (51, '.c')
-    clangxx = (52, '.cpp', 'clang++')
-    make_vg = (54, '.tar', 'make-vg')
-    gcc_32 = (57, '.c', 'gcc-32')
-    clang_32 = (61, '.c', 'clang-32')
-    clangxx_32 = (62, '.cpp', 'clang++-32')
-    gas_32 = (66, '.S', 'gas-32')
-    gas = (67, '.S')
-    rust = (70, '.rs')
-    gas_aarch64 = (101, '.S', 'gas-aarch64')
-    gas_armv7l = (102, '.S', 'gas-armv7l')
-
-
-class AuthData:
-    def __init__(self, login, contest_id, password=None):
-        self.login = login
-        self.contest_id = contest_id
-        self.password = password
-
-
 class BaseProblem:
     def __init__(self, short_name, href):
         self.short_name = short_name
@@ -650,7 +595,7 @@ class FullProblem(SummaryProblem):
         for tag in self._html.find_all(['a', 'img']):
             url = tag['href'] if tag.name == 'a' else tag['src']
             parts = urlsplit(url)
-            if parts.netloc != Links.DOMAIN:
+            if parts.netloc != Links.HOST:
                 continue
             query = parse_qs(parts.query)
             if 'file' in query:
@@ -666,15 +611,14 @@ def get_group_id(contest_id: int) -> str:
     return GROUP_ID_BY_CONTEST.get(contest_id, None)
 
 
+@deprecated(replacement=Links.contest_login)
 def get_contest_url(auth_data):
-    return f'{Links.WEB_CLIENT_ROOT}?contest_id={auth_data.contest_id}'
+    return Links.contest_login(auth_data)
 
 
+@deprecated(reason='Use Links.contest_login(include_creds=True) insted.')
 def get_contest_url_with_creds(auth_data):
-    url = get_contest_url(auth_data)
-    if auth_data.login is not None and auth_data.password is not None:
-        url += f'&login={urlquote(auth_data.login)}&password={urlquote(auth_data.password)}'
-    return url
+    return Links.contest_login(auth_data, include_creds=True)
 
 
 # NOTE all "ejudge_xxx" methods may raise kks.errors.AuthError
